@@ -30,8 +30,10 @@ __all__ = [
     "_save_db",
     "meta",
     "save_zip_db",
+    "add_tabs",
 ]
 
+add_tabs = app.add_tabs
 meta = app.meta
 gridBox = app.gridBox
 set_source = app.set_source
