@@ -16,6 +16,7 @@ from pybi.core.components import (
     TextComponent,
     UploadComponent,
     GridBoxComponent,
+    TabsComponent,
 )
 from pybi.core.components.reactiveComponent import EChart, Slicer, Table, TextValue
 from pybi.core.dataSource import DataSourceField, DataSourceTable, DataView
@@ -51,12 +52,17 @@ class App(ContainerComponent):
         super().__init__(ComponentTag.App)
         self.dataSources: List[DataSource] = []
         self.dataViews: List[DataView] = []
-        # self._data_cps: List[ReactiveComponent] = []
+        self.__dataSetNames = set()
         self._with_temp_host_stack: List[ContainerComponent] = []
         self._clear_data = False
         self.dbLocalStorage = False
         self.__meta = AppMeta(self)
 
+    def __record_and_check_dataset_name(self, name: str):
+        if name in self.__dataSetNames:
+            raise Exception(f"dataset name '{name}' is duplicate")
+        self.__dataSetNames.add(name)
+
     @property
     def meta(self):
         return self.__meta
@@ -71,6 +77,7 @@ class App(ContainerComponent):
 
     def set_source(self, data: pd.DataFrame, *, name: Optional[str] = None):
         name = name or random_ds_name()
+        self.__record_and_check_dataset_name(name)
 
         ds = DataSource(name, data)
         self.dataSources.append(ds)
@@ -85,6 +92,7 @@ class App(ContainerComponent):
     ):
         exclude_source = exclude_source or []
         name = name or random_dv_name()
+        self.__record_and_check_dataset_name(name)
         dv = DataView(name, Sql(sql))
 
         for es in exclude_source:
@@ -167,7 +175,7 @@ class App(ContainerComponent):
         cp = EChart(options)
 
         for info in EChart.extract_infos_from_option(options):
-            cp.add_sql_path(info.path, info._sql.sql)
+            cp.add_sql_path(info)
 
         host = host or self._get_temp_host() or self
         host._add_children(cp)
@@ -225,6 +233,17 @@ class App(ContainerComponent):
         host._add_children(cp)
         return cp
 
+    def add_tabs(
+        self,
+        names: List[str],
+        *,
+        host: Optional[ContainerComponent] = None,
+    ):
+        cp = TabsComponent(names, self)
+        host = host or self._get_temp_host() or self
+        host._add_children(cp)
+        return cp
+
     def save_zip_db(self, path: str):
         with open(path, mode="w", encoding="utf8") as f:
             f.write(ds2sqlite_file_base64(self.dataSources))
@@ -242,52 +261,39 @@ class App(ContainerComponent):
         )
         return data
 
+    def __reset_data(self):
+        """support for run on ipython env"""
+        self.children = []
+        self.dataSources = []
+        self.dataViews = []
+
     def to_json(self):
         return json_dumps_fn(self, indent=2, ensure_ascii=False)
 
     def to_raw_html(self):
-        symbol = '"__{{__config_data__}}___"'
-        # scripts_tag = "<!-- [__other_scripts__] -->"
+        try:
+            symbol = '"__{{__config_data__}}___"'
 
-        # def script2module(name: str):
-        #     file = get_project_root() / "template" / __scripts_mapping__[name]
-        #     return f"<script>{file.read_text()}</script>"
+            config = json_dumps_fn(self, ensure_ascii=False)
 
-        # script_codes = " ".join(script2module(s) for s in self._scripts)
-
-        # config = self.create_config()
-        # self.__reset_data()
-        config = json_dumps_fn(self, ensure_ascii=False)
-
-        with open(
-            get_project_root() / "template/index.html", mode="r", encoding="utf8"
-        ) as html:
-            res = (
-                html.read().replace(symbol, config)
-                # .replace('<div id="app"></div>', f'<div id="app"></div> {script_codes}')
-            )
-            return res
+            with open(
+                get_project_root() / "template/index.html", mode="r", encoding="utf8"
+            ) as html:
+                res = html.read().replace(symbol, config)
+                return res
+        except Exception as e:
+            raise e
+        else:
+            self.__reset_data()
 
     def to_html(self, file):
-        file = Path(file)
-        raw = self.to_raw_html()
-        Path(file).write_text(raw, "utf8")
+        try:
+            file = Path(file)
+            raw = self.to_raw_html()
+            Path(file).write_text(raw, "utf8")
 
-        print(f"to html:{file.absolute()}")
-
-
-def get_all_reaciveComponents(container: ContainerComponent):
-
-    stack = [container]
-
-    while len(stack) > 0:
-        target = stack.pop()
-
-        if isinstance(target, ReactiveComponent) and target._has_filter:
-
-            target._get_sql_mappings()
-
-            yield FilterRecord(target.id, target._updateInfos)
-
-        if isinstance(target, ContainerComponent):
-            stack.append(target)
+            print(f"to html:{file.absolute()}")
+        except Exception as e:
+            raise e
+        else:
+            self.__reset_data()
