@@ -24,7 +24,7 @@ class DataView(Jsonable):
 
     def _to_json_dict(self):
         data = super()._to_json_dict()
-        data["sqlInfo"] = self._sql
+        data["sql"] = self._sql.sql
         data["excludeLinkages"] = self.__excludeLinkages
         return data
 
@@ -68,6 +68,9 @@ class PyechartsPieItem(DataSourceView):
     def __getitem__(self, key):
         from pyecharts import options as opts
 
+        if key > 0:
+            raise StopIteration()
+
         return opts.PieItem("", 0)
 
     def _to_sql(self):
@@ -81,6 +84,31 @@ class PyechartsPieItem(DataSourceView):
         return f"select {name} , {value} from ({self.ds_table._to_sql()})"
 
 
+class PyechartsLineItem(DataSourceView):
+    def __init__(self, ds_table: DataSourceTable) -> None:
+        super().__init__()
+        self.ds_table = ds_table
+
+    def __getitem__(self, key):
+        from pyecharts import options as opts
+
+        if key > 0:
+            raise StopIteration()
+
+        return opts.LineItem("", 0)
+
+    def _to_sql(self):
+
+        if len(self.ds_table.columns) < 3:
+            raise Exception("pie data must have 3 fields")
+
+        series_name = f"{self.ds_table.columns[0]} as sreies"
+        name = f"{self.ds_table.columns[1]} as name"
+        value = f"{self.ds_table.columns[2]} as value"
+
+        return f"select {series_name},{name} , {value} from ({self.ds_table._to_sql()})"
+
+
 class DataSourceTable(DataSourceView):
     def __init__(self, source_name: str, columns: List[str]) -> None:
         super().__init__()
@@ -95,6 +123,9 @@ class DataSourceTable(DataSourceView):
     def to_pyecharts_pie_items(self) -> Any:
         return PyechartsPieItem(self)
 
+    def to_pyecharts_line_items(self) -> Any:
+        return PyechartsLineItem(self)
+
     def _to_sql(self):
         return f"select {','.join(self.columns)} from {self.source_name}"
 
